'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactUikitBase = require('react-uikit-base');

var _reactUikitBase2 = _interopRequireDefault(_reactUikitBase);

var _ufunc = require('ufunc');

var _ufunc2 = _interopRequireDefault(_ufunc);

var _keysToListUq = require('./keysToListUq');

var _keysToListUq2 = _interopRequireDefault(_keysToListUq);

var _tableRows = require('./table-rows');

var _tableRows2 = _interopRequireDefault(_tableRows);

var _tableHead = require('./table-head');

var _tableHead2 = _interopRequireDefault(_tableHead);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Table = function Table(props) {

  // CSS classes
  var cssClassNames = _reactUikitBase2.default.helpers.cleanClasses(['uk-table', props.classes, props.condensed ? 'uk-table-condensed' : null, props.hover ? 'uk-table-hover' : null, props.striped ? 'uk-table-striped' : null, props.className]);

  // Remove non valid html attributes
  var ignoreProps = ['body', 'caption', 'classes', 'condensed', 'hover', 'head', 'kitid', 'numbered', 'columns', 'overflow', 'sort', 'striped'];

  var cleanProps = _reactUikitBase2.default.helpers.cleanProps(ignoreProps)(props);

  // Elements
  var thead = void 0;

  if (props.head) {
    thead = _react2.default.createElement(_tableHead2.default, { numbered: props.numbered, head: props.head, body: props.body });
  }

  var tbody = void 0;

  if (props.body) {
    tbody = _react2.default.createElement(
      'tbody',
      null,
      (0, _tableRows2.default)(props, props.head === '*' ? (0, _keysToListUq2.default)(props.body) : props.head)
    );
  }

  var caption = _ufunc2.default.maybeIf(_react2.default.createElement(
    'caption',
    null,
    props.caption
  ))(props.caption);

  var table = _react2.default.createElement(
    'table',
    _extends({}, cleanProps, {
      className: cssClassNames,
      'data-kitid': props.kitid
    }, _reactUikitBase2.default.events(props)),
    caption,
    thead,
    tbody,
    props.children
  );

  var overflow = _react2.default.createElement(
    'div',
    _extends({}, cleanProps, {
      className: 'uk-overflow-container'
    }),
    table
  );

  // Return Component
  var component = _ufunc2.default.either(overflow, table);
  return component(props.overflow);
};

Table.propTypes = {
  body: _react2.default.PropTypes.array,
  caption: _react2.default.PropTypes.string,
  classes: _react2.default.PropTypes.array,
  className: _react2.default.PropTypes.string,
  condensed: _react2.default.PropTypes.bool,
  hover: _react2.default.PropTypes.bool,
  head: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.array, _react2.default.PropTypes.string]),
  kitid: _react2.default.PropTypes.string,
  numbered: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.bool, _react2.default.PropTypes.string]),
  columns: _react2.default.PropTypes.array,
  overflow: _react2.default.PropTypes.bool,
  sort: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.array, _react2.default.PropTypes.string]),
  striped: _react2.default.PropTypes.bool
};

exports.default = _reactUikitBase2.default.base(Table);